@@ -3,6 +3,6 @@ print.see_check_model <- function(x,
                                   style = theme_lucid,
                                   colors = NULL,
                                   ...) {
-  suppressWarnings(suppressMessages(print(plot(x, style = style, colors = colors, ...))))
+  suppressWarnings(suppressMessages(plot(x, style = style, colors = colors, ...)))
   invisible(x)
 }
