@@ -144,16 +144,8 @@
 }
 
 
-
-.n_unique <- function(x, na.rm = TRUE) {
-  if (isTRUE(na.rm)) x <- stats::na.omit(x)
-  length(unique(x))
-}
-
-
-
 .is_integer <- function(x) {
-  is.numeric(x) && all(floor(x) == x, na.rm = T)
+  is.numeric(x) && all(floor(x) == x, na.rm = TRUE)
 }
 
 
